FirebaseHttpMetric<T> class
- Inheritance
-
- Object
- MonitoringHttpMetric<
HttpMetric> - FirebaseHttpMetric
Constructors
- FirebaseHttpMetric({required String name, required String url, required MonitoringHttpMethod method})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kCanTrace ↔ bool
-
getter/setter pairinherited
- kInstance ↔ HttpMetric?
-
getter/setter pairinherited
- logger ↔ LoggerService?
-
getter/setter pair
- method ↔ MonitoringHttpMethod
-
getter/setter pairinherited
- name ↔ String
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url ↔ String
-
getter/setter pairinherited
Methods
-
getAttribute(
String key) → Future< String?> -
override
-
getAttributes(
) → Future< Map< String, String> > -
override
-
initialize(
{bool autoStart = false, bool canTrace = false}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putAttribute(
String key, String value) → Future< void> -
override
-
setHttpResponseCode(
int code) → dynamic -
override
-
setPayloadSize(
int size, {bool isRequest = false}) → dynamic -
override
-
start(
) → Future< void> -
override
-
stop(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited