FirebaseMonitoringService class
- Inheritance
-
- Object
- LittleFishService
- MonitoringService<
FirebasePerformance, FirebaseHttpMetric, FirebaseTrace> - FirebaseMonitoringService
Constructors
Properties
- core ↔ LittleFishCore
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReady → bool
-
no setterinherited
- isSetup → bool?
-
no setterinherited
- kInstance ↔ FirebasePerformance?
-
getter/setter pairinherited
- logger → LoggerService
-
no setterinherited
- providerName ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings ↔ MonitoringSettings?
-
getter/setter pairinherited
Methods
-
createHttpTrace(
{required String name, required String url, required MonitoringHttpMethod method}) → Future< FirebaseHttpMetric< HttpMetric> > -
override
-
createTrace(
{required String name}) → Future< FirebaseTrace> -
override
-
initailize(
{required MonitoringSettings settings}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIsReady(
{required bool isReady}) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited